@@ -4,11 +4,9 @@ use warnings;
 {
 
     BEGIN {
-        use vars qw[$VERSION];
         use version qw[qv];
-        our $SVN
-            = q[$Id: Block.pm 12 2008-04-10 01:53:19Z sanko@cpan.org $];
-        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 12 $)->numify / 1000;
+        our $SVN = q[$Id: Block.pm 20 2008-05-22 23:09:05Z sanko@cpan.org $];
+        our $VERSION = sprintf q[%.3f], version->new(qw$Rev: 20 $)->numify / 1000;
     }
     use Scalar::Util qw[/weak/];
     use Carp qw[carp];
@@ -18,7 +16,6 @@ use warnings;
 
         sub new {
             my ($class, $args) = @_;
-
             my $self = undef;
             if (    defined $args->{q[piece]}
                 and defined $args->{q[offset]}
@@ -39,67 +36,43 @@ use warnings;
 
         sub piece {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $piece{$self};
         }
 
         sub session {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $piece{$self}->session;
         }
 
         sub client {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $piece{$self}->client;
         }
 
         sub index {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $piece{$self}->index;
         }
 
         sub offset {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $offset{$self};
         }
 
         sub length {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $length{$self};
         }
 
@@ -107,52 +80,36 @@ use warnings;
             my ($self) = @_;
             wantarray
                 ? grep {defined}
-                map    {$_->{q[peer]}} values %{$peer{$self}}
-                : grep {defined $_->{q[peer]}} values %{$peer{$self}};
+                map    { $_->{q[peer]} } values %{$peer{$self}}
+                : grep { defined $_->{q[peer]} } values %{$peer{$self}};
         }
 
         sub _add_peer {
             my ($self, $peer) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             $peer{$self}{$peer} = {peer => $peer, timestamp => time};
             return weaken $peer{$self}{$peer}{q[peer]};
         }
 
         sub _remove_peer {
             my ($self, $peer) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return delete $peer{$self}{$peer};
         }
 
         sub _request_timestamp {
             my ($self, $peer) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return $peer{$self}{$peer}{q[timestamp]};
         }
 
         sub _build_packet_args {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             return (index  => $piece{$self}->index,
                     offset => $offset{$self},
                     length => $length{$self}
@@ -161,24 +118,16 @@ use warnings;
 
         sub _write {
             my ($self) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             $self->client->_do_callback(q[block_write], $self);
             return $piece{$self}->_write($_[1], $offset{$self});
         }
 
         sub as_string {
             my ($self, $advanced) = @_;
-            $piece{$self}->client->_do_callback(
-                                       q[log], TRACE,
-                                       sprintf(q[Entering %s for %s],
-                                               [caller 0]->[3], $$self
-                                       )
-            );
+            $piece{$self}->client->_do_callback(q[log], TRACE,
+                     sprintf(q[Entering %s for %s], [caller 0]->[3], $$self));
             my $dump = $self . q[ [TODO]];
             return print STDERR qq[$dump\n] unless defined wantarray;
             return $dump;
@@ -198,11 +147,11 @@ __END__
 
 =pod
 
-=head1 NAME
+=head1 Name
 
 Net::BitTorrent::Session::Piece::Block - Outgoing request
 
-=head1 CONSTRUCTOR
+=head1 Constructor
 
 =over 4
 
@@ -213,7 +162,7 @@ constructor should not be used directly.
 
 =back
 
-=head1 METHODS
+=head1 Methods
 
 =over 4
 
@@ -266,28 +215,28 @@ object related to this block.
 
 =back
 
-=head1 AUTHOR
+=head1 Author
 
-Sanko Robinson <sanko@cpan.org> - L<http://sankorobinson.com/>
+Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
 
 CPAN ID: SANKO
 
-=head1 LICENSE AND LEGAL
+=head1 License and Legal
 
 Copyright 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.  See
-L<http://www.perl.com/perl/misc/Artistic.html> or the F<LICENSE> file
-included with this module.
+it under the same terms as Perl 5.10 (or higher).  See
+http://www.perl.com/perl/misc/Artistic.html or the F<LICENSE> file
+included with this distribution.
 
-All POD documentation is covered by the Creative Commons
-Attribution-Noncommercial-Share Alike 3.0 License
-(L<http://creativecommons.org/licenses/by-nc-sa/3.0/us/>).
+All POD documentation is covered by the Creative Commons Attribution-
+Noncommercial-Share Alike 3.0 License
+(http://creativecommons.org/licenses/by-nc-sa/3.0/us/).
 
-Neither this module nor the L<AUTHOR|/AUTHOR> is affiliated with
+Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Block.pm 12 2008-04-10 01:53:19Z sanko@cpan.org $
+=for svn $Id: Block.pm 20 2008-05-22 23:09:05Z sanko@cpan.org $
 
 =cut
